# Torrent client

## Install
On Ubuntu from PPA.
```sh
sudo add-apt-repository ppa:colin-i/ppa
```
Or the *manual installation step* from this link *https://gist.github.com/colin-i/e324e85e0438ed71219673fbcc661da6* \
Install:
```sh
sudo apt-get install torra
```
\
On linux distributions, <i>.AppImage</i> file from [releases](https://github.com/colin-i/tora/releases).
\
On Fedora, <i>.rpm</i> file from [releases](https://github.com/colin-i/tora/releases).
```sh
dnf install torra-*.*.rpm
```
\
From [PyPI](https://pypi.org/project/torra):
```sh
pip3 install torra
```

## From source
Using libtorrent (arvidn) with python bindings (example: python3-libtorrent, or unofficial binaries python package python-libtorrent-bin).\
Other requirements are libgtk-4.so.1 and python3-appdirs.\
With setup.py or the other python setup script.

## [Info](https://github.com/colin-i/tora/blob/master/info.md)

## Donations
The *donations* section is here
*https://gist.github.com/colin-i/e324e85e0438ed71219673fbcc661da6*
